<?php
/**
 * WooCommerce Settings Page
 *
 * @package     Barn2\Plugin\WC_Lead_Time\Admin
 * @subpackage  Admin_Settings
 * @author    	Barn2 Media <info@barn2.co.uk>
 * @license     GPL-3.0
 * @copyright	Barn2 Media Ltd
 */

namespace Barn2\Plugin\WC_Lead_Time\Admin;

use Barn2\Lib\Registerable;
use Barn2\Lib\Util;

// Prevent direct file access
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Admin_Settings implements Registerable {
    /**
     * Constructor
     */
	public function __construct( \Barn2_Plugin_License $license ) {
		$this->id		 = 'lead-time';
		$this->label	 = __( 'Lead time', 'woocommerce-lead-time' );
        $this->license   = $license;

        $this->register();
    }

    /**
     * Register hooks and filters
     */
    public function register() {
        // Register settings and section
        add_filter( 'woocommerce_get_sections_products', array( $this, 'register_settings_section' ), 10, 1 );
        add_filter( 'woocommerce_get_settings_products', array( $this, 'get_settings' ), 10, 2 );

        // Sanitize and save license data
        add_filter( 'woocommerce_admin_settings_sanitize_option_' . $this->license->license_key_option, array( $this->license, 'save' ) );

        // Reset to default if empty color
        add_filter( 'woocommerce_admin_settings_sanitize_option_wclt_text_color', array( $this, 'sanitize_text_color' ), 10, 3 );
    }

    /**
	 * Register the settings section
	 *
	 * @since 1.0.0
	 *
	 * @param array $settings
	 * @return array $settings
	 */
	public function register_settings_section( $sections ) {
		$sections[ $this->id ] = $this->label;

		return $sections;
	}

    /**
     * Register section settings
     *
     * @since 1.0.0
     *
     * @param array $settings
     * @param string $current_section
     * @return array $settings
     */
	public function get_settings( $settings, $current_section ) {

        if ( $this->id !== $current_section ) {
            return $settings;
        }

        $plugin_settings = array();


        $plugin_settings[] = array(
            'id' => 'lead_time_settings_start',
            'type' => 'settings_start',
            'class' => 'lead-time-settings'
        );

        $plugin_settings[] = array(
            'title' => __( 'Lead time', 'woocommerce-lead-time' ),
            'type' => 'title',
            'id' => 'lead_time_license_section',
            'desc'	=> '<p>' . __( 'The following options control the WooCommerce Lead Time extension.', 'woocommerce-lead-time' ) . '</p>'
            . '<p>' . Util::barn2_link( 'kb-categories/woocommerce-lead-time-kb', __( 'Documentation', 'woocommerce-lead-time' ), true ) . ' | '
            . Util::barn2_link( 'support-center', __( 'Support', 'woocommerce-lead-time' ), true ) . '</p>',
            'id'    => 'lead_time_options'
        );

        $plugin_settings[] = array(
            'title' => __( 'License key', 'woocommerce-lead-time' ),
            'type' => 'text',
            'id' => $this->license->license_key_option,
            'desc' => $this->license->get_license_key_admin_message(),
            'desc_tip' => __( 'The licence key is contained in your order confirmation email.', 'woocommerce-lead-time' ),
            'class' => 'regular-text'
        );

        if ( filter_input( INPUT_GET, 'license_debug' ) ) {
			$plugin_settings[] = array(
				'type' => 'hidden',
				'id' => 'license_debug',
				'default' => '1'
			);
        }

		if ( $override = filter_input( INPUT_GET, 'license_override', FILTER_SANITIZE_STRING ) ) {
			$plugin_settings[] = array(
				'type' => 'hidden',
				'id' => 'license_override',
				'default' => $override
			);
        }

        $plugin_settings[] = array(
            'title'		        => __( 'Display lead times for', 'woocommerce-lead-time' ),
            'desc'				=> __( 'In stock product', 'woocommerce-lead-time' ),
            'id'				=> 'wclt_display_in_stock',
            'type'				=> 'checkbox',
            'default'           => 'yes',
            'checkboxgroup'		=> 'start',
        );

        $plugin_settings[] = array(
            'desc'			    => __( 'Out of stock product', 'woocommerce-lead-time' ),
            'id'			    => 'wclt_display_out_stock',
            'type'			    => 'checkbox',
            'default'           => 'yes',
            'checkboxgroup'		=> '',
        );

        $plugin_settings[] = array(
            'desc'			    => __( 'Product on backorder', 'woocommerce-lead-time' ),
            'id'			    => 'wclt_display_backorder',
            'type'			    => 'checkbox',
            'default'           => 'yes',
            'checkboxgroup'	    => 'end',
            'desc_tip'          => __( 'Lead time information will be displayed for products with the selected stock statuses.', 'woocommerce-lead-time' ),
        );

        $plugin_settings[] = array(
            'name'		 => __( 'Lead time prefix', 'woocommerce-lead-time' ),
            'id'		 => 'wclt_prefix',
            'type'		 => 'text',
            'desc_tip'	 => __( 'Add text to appear before all lead times, e.g. <i>Lead time:</i>', 'woocommerce-lead-time' ),
        );

        $plugin_settings[] = array(
            'name'		 => __( 'Global lead time', 'woocommerce-lead-time' ),
            'id'		 => 'wclt_global_time',
            'type'		 => 'text',
            'desc_tip'	 => __( 'Enter a lead time for all products. Can be overridden for individual products', 'woocommerce-lead-time' ),
        );

        $plugin_settings[] = array(
            'title'    => __( 'Lead time text color', 'woocommerce-lead-time' ),
            /* translators: %s: default color */
            'desc'     => sprintf( __( 'The lead time text color. Default %s.', 'woocommerce-lead-time' ), '<code>#60646c</code>' ),
            'id'       => 'wclt_text_color',
            'type'     => 'color',
            'css'      => 'width:6em;height: 30px;margin-top: -3px;',
            'default'  => '#60646c',
            'desc_tip' => true,
        );

        $plugin_settings[] = array(
            'type' => 'sectionend',
            'id'   => 'lead_time_options',
        );

        $plugin_settings[] = array(
            'id' => 'lead_time_settings_end',
            'type' => 'settings_end'
        );

        return $plugin_settings;
    }

    /**
     * Handle empty color value and set back to default.
     *
     * @since 1.0.0
     *
     * @param string $value
     * @return string $value
     */
    public function sanitize_text_color( $value ) {
        if ( empty( $value ) ) {
            $value = '#60646c';
        }

        return $value;
    }
}