<?php
/**
 * Display handler
 *
 * @package     Barn2\Plugin\WC_Lead_Time
 * @subpackage  Display
 * @author    	Barn2 Media <info@barn2.co.uk>
 * @license     GPL-3.0
 * @copyright	Barn2 Media Ltd
 */

namespace Barn2\Plugin\WC_Lead_Time;

use Barn2\Lib\Registerable;

// Prevent direct file access
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Display implements Registerable {
	/**
	 * Instance of this class.
	 *
	 * @since    1.0.0
	 *
	 * @var      object
	 */
	protected static $instance = null;

	/**
	 * Return an instance of this class.
	 *
	 * @since     1.0.0
	 *
	 * @return    object    A single instance of this class.
	 */
	public static function get_instance() {
		// If the single instance hasn't been set, set it now.
		if ( null == self::$instance ) {
			self::$instance = new self;
			self::$instance->register();
		}

		return self::$instance;
    }

    /**
     * Register hooks and filters
     *
     * @since 1.0.0
     */
    public function register() {
        add_filter( 'woocommerce_get_stock_html', array( $this, 'maybe_add_lead_time_stock_html' ), 10, 2 );
        add_filter( 'woocommerce_get_availability_text', array( $this, 'maybe_add_lead_time_availability_text' ), 10, 2 );
    }

    /**
     * Display lead time inside availability
     *
     * @since 1.0.0
     *
     * @param string $availability
     * @param WC_Product $product
     * @return string $availability
     */
    public function maybe_add_lead_time_availability_text( $availability, $product ) {
        if ( apply_filters( 'wclt_disable_default_output', false ) ) {
            return $availability;
        }

        if ( ! $this->is_visible( $product ) || empty( $availability ) || ! is_product() ) {
            return $availability;
        }

        $lead_time = $this->get_lead_time( $product );

        if ( ! $lead_time ) {
            return $availability;
        }

        $text_color = get_option( 'wclt_text_color', '#60646c' );
        $availability .= sprintf( '<span style="color: %s;" class="wclt_lead_time">&nbsp;| %s</span>', $text_color, $lead_time );

        return $availability;
    }

    /**
     * Display lead time if conditions are met
     *
     * @since 1.0.0
     *
     * @param string $html
     * @param WC_Product $product
     * @return string $html
     */
    public function maybe_add_lead_time_stock_html( $html, $product ) {
        if ( apply_filters( 'wclt_disable_default_output', false ) ) {
            return $html;
        }

        if ( ! $this->is_visible( $product ) ) {
            return $html;
        }

        $availability = $product->get_availability();

        if ( ! empty( $availability['availability'] ) ) {
            return $html;
        }

        $lead_time = $this->get_lead_time( $product );

        if ( ! $lead_time ) {
            return $html;
        }

        $text_color = get_option( 'wclt_text_color', '#60646c' );
        $html .= sprintf( '<p style="color: %s;" class="stock wclt_lead_time">%s</p>', $text_color, $lead_time );

        return $html;
    }

    /**
     * Determine if lead time should be visible on the product
     *
     * @since 1.0.0
     *
     * @param WC_Product $product
     * @return boolean
     */
    private function is_visible( $product ) {
        $stock_status = $product->get_stock_status();
        $display = array(
            'instock'       => get_option( 'wclt_display_in_stock', 'yes' ),
            'outofstock'    => get_option( 'wclt_display_out_stock', 'yes' ),
            'onbackorder'   => get_option( 'wclt_display_backorder', 'yes' ),
        );

        if ( $display[ $stock_status ] === 'yes' ) {
            return true;
        }

        return false;
    }

    /**
     * Get the global or individual lead time for the product
     *
     * @since 1.0.0
     *
     * @param WC_Product $product
     * @return string
     */
    public static function get_lead_time( $product ) {
        $prefix = get_option( 'wclt_prefix' );

        // if variation get parent $product
        if ( $product->is_type( 'variation' ) ) {
            $product = wc_get_product( $product->get_parent_id() );
        }

        $lead_time = $product->get_meta( '_wclt_lead_time' );

        // check if individual lead time is empty and get global
        if ( empty( $lead_time ) ) {
            $lead_time = get_option( 'wclt_global_time' );
        }

        // check if lead time is still empty
        if ( empty( $lead_time ) ) {
            return false;
        }

        // output with our without prefix
        if ( empty( $prefix ) ) {
            $output = $lead_time;
        } else {
            $output = sprintf( '%s %s', $prefix, $lead_time );
        }

        return $output;
    }
}