<?php

/**
 * Main Plugin Class.
 *
 * @package     Barn2\Plugin\WC_Lead_Time
 * @subpackage  Plugin
 * @author    	Barn2 Media <info@barn2.co.uk>
 * @license     GPL-3.0
 * @copyright	Barn2 Media Ltd
 */
namespace Barn2\Plugin\WC_Lead_Time;

use Barn2\Plugin\WC_Lead_Time\Admin\Admin;
use Barn2\Plugin\WC_Lead_Time\Admin\Admin_Settings;
use Barn2\Plugin\WC_Lead_Time\Admin\Product_Data;
use Barn2\Plugin\WC_Lead_Time\Integration\Product_Table_Integration;
use Barn2\Lib\Util;

// Prevent direct file access
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Plugin {

    /**
     * Plugin license manager
     *
     * @since	1.0.0
     *
     * @var 	object
     */
    private $license;

    /**
     * Admin settings instance
     *
     * @since	1.0.0
     *
     * @var 	Barn2\Plugin\WC_Lead_Time\Admin\Admin_Settings
     */
    private $admin;

    /**
     * Product Table integration instance
     *
     * @since	1.0.0
     *
     * @var 	Barn2\Plugin\WC_Lead_Time\Integration\Product_Table_Integration
     */
    private $product_table;

    /**
     * The variable name is used as the text domain when internationalizing strings
     * of text. Its value should match the Text Domain file header in the main
     * plugin file.
     *
     * @since    1.0.0
     *
     * @var      string
     */
    protected $plugin_slug = 'woocommerce-lead-time';

    /**
     * Instance of this class.
     *
     * @since    1.0.0
     *
     * @var      object
     */
    protected static $instance = null;

    /**
     * Return an instance of this class.
     *
     * @since     1.0.0
     *
     * @return    object    A single instance of this class.
     */
    public static function get_instance() {

        // If the single instance hasn't been set, set it now.
        if ( null == self::$instance ) {
            self::$instance = new self;
        }

        return self::$instance;
    }

    /**
     * Constructor
     */
    public function __construct() {
        $this->define_constants();
        $this->load_textdomain();
        $this->require_license_files();
        $this->require_functions();

        // Create plugin license & updater.
        $this->license = new \Barn2_Plugin_License( WCLT_PLUGIN_FILE, WCLT_PLUGIN_NAME, WCLT_PLUGIN_VERSION, 'wc_lead_time' );
        $this->init();
    }

    /**
     * Initialise classes
     */
    public function init() {
        if ( ! Util::is_woocommerce_active() ) {
            return;
        }

        // load admin before license check for license entry
        if ( Util::is_admin() ) {
            Admin::get_instance();
            $this->admin = new Admin_Settings( $this->license );
        }

        if ( $this->license->is_valid() ) {
            if ( Util::is_admin() ) {
                Product_Data::get_instance();
            }

            Display::get_instance();

            if ( Util::is_front_end() ) {
                $this->product_table = new Product_Table_Integration();
                $this->product_table->register();
            }
        }
    }

    /**
     * Return the plugin slug.
     *
     * @since    1.0.0
     *
     * @return   Plugin slug variable.
     */
    public function get_plugin_slug() {
        return $this->plugin_slug;
    }

    /**
     * Require the license library files
     *
     * @since 1.0.0
     */
    private function require_license_files() {
        require_once dirname( WCLT_PLUGIN_FILE ) . '/license/class-b2-plugin-license.php';
    }

    /**
     * Require the unnamespaced functions file
     *
     * @since 1.0.0
     */
    private function require_functions() {
        require_once dirname( WCLT_PLUGIN_FILE ) . '/functions/wclt-functions.php';
    }

    /**
     * Setup constants
     *
     * @since 1.0,0
     */
    private function define_constants() {
        if ( ! defined( 'WCLT_PLUGIN_BASENAME' ) ) {
            define( 'WCLT_PLUGIN_BASENAME', plugin_basename( WCLT_PLUGIN_FILE ) );
        }

        if ( ! defined( 'WCLT_PLUGIN_NAME' ) ) {
            define( 'WCLT_PLUGIN_NAME', 'WooCommerce Lead Time' );
        }

        if ( ! defined( 'WCLT_PLUGIN_VERSION' ) ) {
            define( 'WCLT_PLUGIN_VERSION', '1.0.1' );
        }
    }

    /**
     * Load the plugin language file for i18n
     *
     * @since 1.0.0
     */
    private function load_textdomain() {
        load_plugin_textdomain( 'woocommerce-lead-time', false, plugin_basename( dirname( WCLT_PLUGIN_FILE ) ) . '/languages' );
    }

}
